/*
 * See Licensing and Copyright notice in naev.h
 */
#pragma once

#include "nlua.h"

/*
 * Library loading
 */
int nlua_loadCamera( nlua_env env );
